# frozen_string_literal: true

require_dependency 'auth1/application_controller'

module Auth1
  class SessionsController < ApplicationController
    def callback
      # This stores all the user information that came from Auth0 and the IdP
      # See also: https://github.com/auth0/omniauth-auth0#authentication-hash
      session[:userinfo] = request.env['omniauth.auth']

      # Redirect to the URL you want after successful auth
      redirect_to request.env['omniauth.origin']
    end

    def failure
      # show a failure page or redirect to an error page
      @error_msg = request.params['message']
    end

    def logout
      reset_session
      redirect_to auth0_logout_url
    end

    private

    def auth0_logout_url
      request_params = {
        client_id: ENV['AUTH0_CLIENT_ID'],
        returnTo: ENV['AUTH0_LOGOUT_URL']
      }

      URI::HTTPS.build(
        host: ENV['AUTH0_DOMAIN'],
        path: '/v2/logout',
        query: request_params.to_query
      ).to_s
    end
  end
end
