# frozen_string_literal: true

module Auth1
  module SessionsHelper
    def login_path
      '/auth/auth0'
    end

    def login_button(name = 'Login', options = nil, html_options = nil, &block)
      options ||= login_path
      html_options ||= {}
      html_options[:method] = :post
      button_to(name, options, html_options, &block)
    end

    def logout_button(name = 'Logout', options = nil, html_options = nil, &block)
      options ||= auth1.logout_path
      html_options ||= {}
      html_options[:method] = :get
      button_to(name, options, html_options, &block)
    end

    def login_or_logout_button(name = %w[Login Logout], options = [nil, nil], html_options = [nil, nil], &block)
      if logged_in?
        logout_html_options = html_options[1] || {}
        logout_html_options[:method] = :get
        logout_button(name[1], options[1], logout_html_options, &block)
      else
        login_html_options = html_options[0] || {}
        login_html_options[:method] = :post
        login_button(name[0], options[0], login_html_options, &block)
      end
    end

    def login_link(name = 'Login', options = nil, html_options = nil, &block)
      options ||= login_path
      html_options ||= {}
      html_options[:method] = :post
      link_to(name, options, html_options, &block)
    end

    def logout_link(name = 'Logout', options = nil, html_options = nil, &block)
      options ||= auth1.logout_path
      html_options ||= {}
      html_options[:method] = :get
      link_to(name, options, html_options, &block)
    end

    def login_or_logout_link(name = %w[Login Logout], options = [nil, nil], html_options = [nil, nil], &block)
      if logged_in?
        logout_html_options = html_options[1] || {}
        logout_html_options[:method] = :get
        logout_link(name[1], options[1], logout_html_options, &block)
      else
        login_html_options = html_options[0] || {}
        login_html_options[:method] = :post
        login_link(name[0], options[0], login_html_options, &block)
      end
    end

    def logged_in?
      session['userinfo'].present?
    end

    def logged_out?
      !logged_in?
    end
  end
end
